# QFITS CHECK XMEMORY  
#----------------
# Checks for the Qfits library and header files.
# Implemented with the same behaviour as the original configure script in 
# QFITS 540.
# The only difference is that the previous options
#   --xmemory-mode=M
#   --max-ptrs=MAXPTRS
# are now impleemented as:
#   --enable-xemory-mode=M
#   --enable-max-ptrs=MAXPTRS


AC_DEFUN([QFITS_CHECK_XMEMORY],
[

    AC_MSG_CHECKING([Qfits options])

    AC_ARG_ENABLE(xmemory-mode,
                AC_HELP_STRING([--enable-xmemory-mode=M],
                               [where M=0 switches off the internal xmemory
                                handling, M=1 exits the program
                                whenever a memory allocation fails
                                M=2 switches on the internal xmemory
                                handling]),
                [
                    qfits_xmemory_flag=yes
                    # $enableval=yes when no argument is given
                    qfits_xmemory_mode=$enableval
                ])

    AC_ARG_ENABLE(max-ptrs,
                AC_HELP_STRING([--enable-max-ptrs=MAXPTRS],
                               [MAXPTRS Set MAXPTRS as the maximum number of
				pointers allowed]),
                [
                    qfits_max_ptrs_flag=yes
                    qfits_max_ptrs=$enableval
                ])

    # Pending: check qfits_max_ptrs is numeric, otherwise AC_MSG_ERROR 
    if test "x$qfits_max_ptrs_flag" = xyes ; then
        QFITS_MAXPTRS_CFLAGS="-DXMEMORY_MAXPTRS=$qfits_max_ptrs"
        AC_MSG_WARN([qfits with max-ptrs enable!])
    else
        QFITS_MAXPTRS_CFLAGS=""
        AC_MSG_WARN([qfits with max-ptrs disable!])
    fi

    if test "x$qfits_xmemory_flag" = xyes ; then
        QFITS_CFLAGS="-DXMEMORY_MODE=$qfits_xmemory_mode"
        case $qfits_xmemory_mode in
        yes)        
          QFITS_CFLAGS="-DXMEMORY_MODE=0 -DXMEMORY_MAXPRS=1" 
          break ;;
        0|1)        
          QFITS_CFLAGS="-DXMEMORY_MODE=$qfits_xmemory_mode -DXMEMORY_MAXPRS=1" 
          break ;;
        2)        
          QFITS_CFLAGS="-DXMEMORY_MODE=2 $QFITS_MAXPTRS_CFLAGS" 
          break ;;
        *)
          AC_MSG_ERROR([Option --enable-xmemory-mode=$qfits_xmemory_mode not valid. Please check!])
          break ;;
        esac

        AC_MSG_WARN([qfits with xmemory-mode enable!])
    else
        QFITS_CFLAGS="$QFITS_MAXPTRS_CFLAGS" 
        AC_MSG_WARN([qfits with xmemory-mode disabled!])
    fi

    AC_MSG_RESULT([QFITS_CFLAGS=$QFITS_CFLAGS])
    AC_SUBST(QFITS_CFLAGS)
])
